@@ -13,14 +13,16 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-#ifndef STREAM_5_3_1_TAGGER_H
-#define STREAM_5_3_1_TAGGER_H
+#ifndef STREAM_5_3_3_TAGGER_H
+#define STREAM_5_3_3_TAGGER_H
 
 #include "apertium_config.h"
 
 #include "analysis.h"
-#include "basic_5_3_1_tagger.h"
+#include "basic_5_3_3_tagger.h"
 #include "basic_stream_tagger.h"
+#include "i.h"
+#include "lemma.h"
 
 #include <istream>
 
@@ -31,23 +33,30 @@
 #endif // ENABLE_DEBUG
 
 namespace Apertium {
-class Stream_5_3_1_Tagger : private basic_5_3_1_Tagger,
+class Stream_5_3_3_Tagger : private basic_5_3_3_Tagger,
                             public basic_StreamTagger {
 public:
-  Stream_5_3_1_Tagger(const Flags &Flags_);
+  Stream_5_3_3_Tagger(const Flags &Flags_);
   void deserialise(std::istream &Serialised_basic_Tagger);
 
 private:
   long double score(const Analysis &Analysis_) const;
-  long double tokenCount_T(const Analysis &Analysis_) const;
+  long double tokenCount_r_i(const Analysis &Analysis_) const;
+  long double tokenCount_i(const Analysis &Analysis_) const;
+  long double typeCount_i(const Analysis &Analysis_) const;
+  long double tokenCount_d_i_Morpheme(const Lemma &Lemma_, const i &i_) const;
+  long double tokenCount_i_d_Morpheme(const i &i_, const Lemma &Lemma_) const;
+  long double tokenCount_i_Morpheme(const i &i_) const;
+  long double typeCount_i_Morpheme(const i &i_, const Lemma &Lemma_) const;
+  long double tokenCount_d_Morpheme(const Lemma &Lemma_) const;
+  long double typeCount_d_Morpheme(const Lemma &Lemma_, const i &i_) const;
 
 #if ENABLE_DEBUG
 
   std::wstring score_DEBUG(const Analysis &Analysis_) const;
 
 #endif // ENABLE_DEBUG
-
 };
 }
 
-#endif // STREAM_5_3_1_TAGGER_H
+#endif // STREAM_5_3_3_TAGGER_H
